$reps = {
    'PREFIX' => "usr",
    'TMP_FILE_LOC' => "debian/tmp",
    'HTML_FILE_LOC' => "debian/html",
    'TOPDIR' => "/home/broonie/src/packages/xemacs21/xemacs21-packages-2009.02.17.dfsg.2",
    'MAJVERSION' => "21",
    'ARCH' => "amd64",
    'VERSION' => "2009.02.17.dfsg.2",
    'SUBNAME' => "",
    'CONF_NAME' => "amd64-debian-linux",
};
